Enum Request
#[non_exhaustive]pub enum Request<'a> {
Destroy,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the ext_foreign_toplevel_handle_v1 object
This request should be used when the client will no longer use the handle or after the closed event has been received to allow destruction of the object.
When a handle is destroyed, a new handle may not be created by the server until the toplevel is unmapped and then remapped. Destroying a toplevel handle is not recommended unless the client is cleaning up child objects before destroying the ext_foreign_toplevel_list_v1 object, the toplevel was closed or the toplevel handle will not be used in the future.
Other protocols which extend the ext_foreign_toplevel_handle_v1 interface should require destructors for extension interfaces be called before allowing the toplevel handle to be destroyed.
This is a destructor, once sent this object cannot be used any longer.
Implementations