Struct ExtForeignToplevelHandleV1
pub struct ExtForeignToplevelHandleV1 { /* private fields */ }wayland and Linux only.Expand description
a mapped toplevel
A ext_foreign_toplevel_handle_v1 object represents a mapped toplevel window. A single app may have multiple mapped toplevels.
See also the Event enum for this interface.
Implementations
impl ExtForeignToplevelHandleV1
impl ExtForeignToplevelHandleV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the ext_foreign_toplevel_handle_v1 object
This request should be used when the client will no longer use the handle or after the closed event has been received to allow destruction of the object.
When a handle is destroyed, a new handle may not be created by the server until the toplevel is unmapped and then remapped. Destroying a toplevel handle is not recommended unless the client is cleaning up child objects before destroying the ext_foreign_toplevel_list_v1 object, the toplevel was closed or the toplevel handle will not be used in the future.
Other protocols which extend the ext_foreign_toplevel_handle_v1 interface should require destructors for extension interfaces be called before allowing the toplevel handle to be destroyed.